Module json

Module json 

JSON types that show up in the parsed glTF structure.

Structs

Object
A JSON object (i.e. a map from strings to Values).

Enums

Value
A JSON value. Unlike serde_jsons Value type, this type can borrow from the input data instead of always copying, reducing memory usage in multiple cases.