Accessor

Struct Accessor 

pub struct Accessor<'a> {
    pub name: Option<Cow<'a, str>>,
    pub buffer_view: Idx<BufferView<'static>>,
    pub byte_offset: u64,
    pub ty: ElementType<'a>,
    pub component_type: ComponentType,
    pub normalized: bool,
    pub count: u64,
    pub max: Option<Vec<Number>>,
    pub min: Option<Vec<Number>>,
    pub sparse: Option<Sparse<'a>>,
    pub extensions: Option<Extensions<'a>>,
    pub extras: Option<Extras<'a>>,
}
A typed view into a buffer view that contains raw binary data.

Fields

name: Option<Cow<'a, str>>

The user-defined name of this object.

buffer_view: Idx<BufferView<'static>>

The index of the buffer view.

byte_offset: u64

The offset relative to the start of the buffer view in bytes.

ty: ElementType<'a>

Specifies if the accessor’s elements are scalars, vectors, or matrices.

component_type: ComponentType

The data type of the accessor’s components.

normalized: bool

Specifies whether integer data values are normalized to [0, 1] (for unsigned types) or to [-1, 1] (for signed types) when they are accessed.

count: u64

The number of elements referenced by this accessor.

max: Option<Vec<Number>>

Maximum value of each component in this accessor.

min: Option<Vec<Number>>

Minimum value of each component in this accessor.

sparse: Option<Sparse<'a>>

Sparse storage of elements that deviate from their initialization value.

extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>

Implementations

Source

impl Accessor<'_>

pub fn into_owned(self) -> Accessor<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.