AlphaMode

Struct AlphaMode 

pub struct AlphaMode<'a>(pub Cow<'a, str>);
The alpha rendering mode of a material.

Tuple Fields

0: Cow<'a, str>

Implementations

Source

impl AlphaMode<'_>

pub fn into_owned(self) -> AlphaMode<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl AlphaMode<'_>

pub const OPAQUE: Self

pub const MASK: Self

pub const BLEND: Self

pub fn to_enum(&self) -> Option<AlphaModeEnum>