Animation

Struct Animation 

pub struct Animation<'a> {
    pub name: Option<Cow<'a, str>>,
    pub samplers: Vec<AnimationSampler<'a>>,
    pub channels: Vec<Channel<'a>>,
    pub extensions: Option<Extensions<'a>>,
    pub extras: Option<Extras<'a>>,
}
A keyframe animation.

Fields

name: Option<Cow<'a, str>>

The user-defined name of this object.

samplers: Vec<AnimationSampler<'a>>

An array of animation samplers.

channels: Vec<Channel<'a>>

An array of animation channels.

extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>

Implementations

Source

impl Animation<'_>

pub fn into_owned(self) -> Animation<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.