pub struct AnimationSampler<'a> {
pub input: Idx<Accessor<'static>>,
pub output: Idx<Accessor<'static>>,
pub interpolation: Interpolation<'a>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
An animation sampler combines timestamps with a sequence of output values and defines an interpolation algorithm.
Fields
input: Idx<Accessor<'static>>The index of an accessor containing keyframe timestamps.
output: Idx<Accessor<'static>>The index of an accessor containing keyframe output values.
interpolation: Interpolation<'a>Interpolation algorithm.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations
Sourceimpl AnimationSampler<'_>
impl AnimationSampler<'_>
Sourcepub fn into_owned(self) -> AnimationSampler<'static>
pub fn into_owned(self) -> AnimationSampler<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.