Attribute

Struct Attribute 

pub struct Attribute<'a>(pub Cow<'a, str>);
A vertex attribute semantic.

Tuple Fields

0: Cow<'a, str>

Implementations

Source

impl Attribute<'_>

pub fn into_owned(self) -> Attribute<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl Attribute<'_>

pub const POSITION: Self

pub const NORMAL: Self

pub const TANGENT: Self

pub fn to_enum(&self) -> Option<AttributeEnum>

pub fn texcoord(n: u16) -> Self

pub fn color(n: u16) -> Self

pub fn joints(n: u16) -> Self

pub fn weights(n: u16) -> Self