BufferView

Struct BufferView 

pub struct BufferView<'a> {
    pub name: Option<Cow<'a, str>>,
    pub buffer: Idx<Buffer<'static>>,
    pub byte_offset: u64,
    pub byte_length: u64,
    pub byte_stride: Option<u64>,
    pub target: Option<BufferViewTarget>,
    pub extensions: Option<Extensions<'a>>,
    pub extras: Option<Extras<'a>>,
}
A view into a buffer generally representing a subset of the buffer.

Fields

name: Option<Cow<'a, str>>

The user-defined name of this object.

buffer: Idx<Buffer<'static>>

The index of the buffer.

byte_offset: u64

The offset into the buffer in bytes.

byte_length: u64

The length of the buffer view in bytes.

byte_stride: Option<u64>

The stride, in bytes, between vertex attributes.

target: Option<BufferViewTarget>

The hint representing the intended GPU buffer type to use with this buffer view.

extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>

Implementations

Source

impl BufferView<'_>

pub fn into_owned(self) -> BufferView<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.