BufferViewTarget

Struct BufferViewTarget 

pub struct BufferViewTarget(pub u64);
A hint of the intended GPU buffer type to use with a buffer view.

Tuple Fields

0: u64

Implementations

Source

impl BufferViewTarget

pub fn into_owned(self) -> BufferViewTarget

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl BufferViewTarget