pub struct CameraType<'a>(pub Cow<'a, str>);Expand description
Type of camera projection.
Tuple Fields
0: Cow<'a, str>Implementations
Sourceimpl CameraType<'_>
impl CameraType<'_>
Sourcepub fn into_owned(self) -> CameraType<'static>
pub fn into_owned(self) -> CameraType<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.
Sourceimpl CameraType<'_>
impl CameraType<'_>
pub const PERSPECTIVE: Self
pub const ORTHOGRAPHIC: Self
pub fn to_enum(&self) -> Option<CameraTypeEnum>