pub struct Channel<'a> {
pub sampler: Idx<AnimationSampler<'static>>,
pub target: ChannelTarget<'a>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
An animation channel combines an animation sampler with a target property being animated.
Fields
sampler: Idx<AnimationSampler<'static>>The index of a sampler in an animation used to compute the value for the target.
target: ChannelTarget<'a>The descriptor of the animated property.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations