pub struct ChannelTarget<'a> {
pub node: Option<Idx<Node<'static>>>,
pub path: Property<'a>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
The descriptor of an animated property.
Fields
node: Option<Idx<Node<'static>>>The index of the node to animate.
path: Property<'a>The name of the node’s TRS property to animate, or the weights of the Morph Targets it
instantiates.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations
Sourceimpl ChannelTarget<'_>
impl ChannelTarget<'_>
Sourcepub fn into_owned(self) -> ChannelTarget<'static>
pub fn into_owned(self) -> ChannelTarget<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.