ComponentType

Struct ComponentType 

pub struct ComponentType(pub u64);
Data type of an accessor’s components.

Tuple Fields

0: u64

Implementations

Source

impl ComponentType

pub fn into_owned(self) -> ComponentType

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl ComponentType

pub const I8: Self

pub const U8: Self

pub const I16: Self

pub const U16: Self

pub const U32: Self

pub const F32: Self

pub fn to_enum(self) -> Option<ComponentTypeEnum>