pub struct Extensions<'a>(pub Object<'a>);Expand description
JSON object with extension-specific objects.
Tuple Fields
0: Object<'a>Implementations
Sourceimpl Extensions<'_>
impl Extensions<'_>
Sourcepub fn into_owned(self) -> Extensions<'static>
pub fn into_owned(self) -> Extensions<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.