pub struct Filter(pub u64);Expand description
Sampling filter.
Tuple Fields
0: u64Implementations
Sourceimpl Filter
impl Filter
Sourcepub fn into_owned(self) -> Filter
pub fn into_owned(self) -> Filter
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.
Sourceimpl Filter
impl Filter
pub const NEAREST: Self
pub const LINEAR: Self
pub const NEAREST_MIPMAP_NEAREST: Self
pub const LINEAR_MIPMAP_NEAREST: Self
pub const NEAREST_MIPMAP_LINEAR: Self
pub const LINEAR_MIPMAP_LINEAR: Self
pub fn to_enum(self) -> Option<FilterEnum>