pub struct Interpolation<'a>(pub Cow<'a, str>);Expand description
Interpolation algorithm.
Tuple Fields
0: Cow<'a, str>Implementations
Sourceimpl Interpolation<'_>
impl Interpolation<'_>
Sourcepub fn into_owned(self) -> Interpolation<'static>
pub fn into_owned(self) -> Interpolation<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.
Sourceimpl Interpolation<'_>
impl Interpolation<'_>
pub const LINEAR: Self
pub const STEP: Self
pub const CUBICSPLINE: Self
pub fn to_enum(&self) -> Option<InterpolationEnum>