Mode

Struct Mode 

pub struct Mode(pub u64);
The topology type of a set primitives to render.

Tuple Fields

0: u64

Implementations

Source

impl Mode

pub fn into_owned(self) -> Mode

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl Mode

pub const POINTS: Self

pub const LINES: Self

pub const LINE_LOOP: Self

pub const LINE_STRIP: Self

pub const TRIANGLES: Self

pub const TRIANGLE_STRIP: Self

pub const TRIANGLE_FAN: Self

pub fn to_enum(self) -> Option<ModeEnum>