OcclusionTextureInfo

Struct OcclusionTextureInfo 

pub struct OcclusionTextureInfo<'a> {
    pub inner: TextureInfo<'a>,
    pub strength: f32,
}
Reference to an occlusion texture.

Fields

inner: TextureInfo<'a>strength: f32

A scalar multiplier controlling the amount of occlusion applied.

Implementations

Source

impl OcclusionTextureInfo<'_>

pub fn into_owned(self) -> OcclusionTextureInfo<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.