PbrMetallicRoughness

Struct PbrMetallicRoughness 

pub struct PbrMetallicRoughness<'a> {
    pub base_color_texture: Option<TextureInfo<'a>>,
    pub metallic_roughness_texture: Option<TextureInfo<'a>>,
    pub base_color_factor: [f32; 4],
    pub metallic_factor: f32,
    pub roughness_factor: f32,
    pub extensions: Option<Extensions<'a>>,
    pub extras: Option<Extras<'a>>,
}
A set of parameter values that are used to define the metallic-roughness material model from Physically-Based Rendering (PBR) methodology.

Fields

base_color_texture: Option<TextureInfo<'a>>

The base color texture.

metallic_roughness_texture: Option<TextureInfo<'a>>base_color_factor: [f32; 4]

The factors for the base color of the material.

metallic_factor: f32

The factor for the metalness of the material.

roughness_factor: f32

The factor for the roughness of the material,

extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>

Implementations

Source

impl PbrMetallicRoughness<'_>

pub fn into_owned(self) -> PbrMetallicRoughness<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.