pub struct Perspective<'a> {
pub aspect_ratio: Option<f32>,
pub yfov: f32,
pub zfar: Option<f32>,
pub znear: f32,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
A perspective camera containing properties to create a perspective projection matrix.
Fields
aspect_ratio: Option<f32>The floating-point aspect ratio of the field of view.
yfov: f32The floating-point vertical field of view in radians.
zfar: Option<f32>The floating-point distance to the far clipping plane.
znear: f32The floating-point distance to the near clipping plane.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations
Sourceimpl Perspective<'_>
impl Perspective<'_>
Sourcepub fn into_owned(self) -> Perspective<'static>
pub fn into_owned(self) -> Perspective<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.