Root

Struct Root 

pub struct Root<'a> {
Show 19 fields pub asset: Asset<'a>, pub extensions_used: Vec<Cow<'a, str>>, pub extensions_required: Vec<Cow<'a, str>>, pub scene: Option<Idx<Scene<'static>>>, pub accessors: Vec<Accessor<'a>>, pub animations: Vec<Animation<'a>>, pub buffers: Vec<Buffer<'a>>, pub buffer_views: Vec<BufferView<'a>>, pub cameras: Vec<Camera<'a>>, pub images: Vec<Image<'a>>, pub materials: Vec<Material<'a>>, pub meshes: Vec<Mesh<'a>>, pub nodes: Vec<Node<'a>>, pub samplers: Vec<Sampler<'a>>, pub scenes: Vec<Scene<'a>>, pub skins: Vec<Skin<'a>>, pub textures: Vec<Texture<'a>>, pub extensions: Option<Extensions<'a>>, pub extras: Option<Extras<'a>>,
}
The root object of a glTF asset.

Fields

asset: Asset<'a>

Metadata about this glTF asset.

extensions_used: Vec<Cow<'a, str>>

Names of glTF extensions used in this asset.

extensions_required: Vec<Cow<'a, str>>

Names of glTF extensions required to properly load this asset.

scene: Option<Idx<Scene<'static>>>

The index of the default scene.

accessors: Vec<Accessor<'a>>

An array of accessors.

animations: Vec<Animation<'a>>

An array of animations.

buffers: Vec<Buffer<'a>>

An array of buffers.

buffer_views: Vec<BufferView<'a>>

An array of buffer views.

cameras: Vec<Camera<'a>>

An array of cameras.

images: Vec<Image<'a>>

An array of images.

materials: Vec<Material<'a>>

An array of materials.

meshes: Vec<Mesh<'a>>

An array of meshes.

nodes: Vec<Node<'a>>

An array of nodes.

samplers: Vec<Sampler<'a>>

An array of samplers.

scenes: Vec<Scene<'a>>

An array of scenes.

skins: Vec<Skin<'a>>

An array of skins.

textures: Vec<Texture<'a>>

An array of textures.

extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>

Implementations

Source

impl Root<'_>

pub fn into_owned(self) -> Root<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl<'a> Root<'a>

pub fn from_str(s: &'a str) -> Result<Self>

Reads a glTF JSON from the given string.