Sampler

Struct Sampler 

pub struct Sampler<'a> {
    pub name: Option<Cow<'a, str>>,
    pub mag_filter: Option<Filter>,
    pub min_filter: Option<Filter>,
    pub wrap_s: Wrap,
    pub wrap_t: Wrap,
    pub extensions: Option<Extensions<'a>>,
    pub extras: Option<Extras<'a>>,
}
Texture sampler properties for filtering and wrapping modes.

Fields

name: Option<Cow<'a, str>>

The user-defined name of this object.

mag_filter: Option<Filter>

Magnification filter.

min_filter: Option<Filter>

Minification filter.

wrap_s: Wrap

S (U) wrapping mode.

wrap_t: Wrap

T (V) wrapping mode.

extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>

Implementations

Source

impl Sampler<'_>

pub fn into_owned(self) -> Sampler<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.