pub struct Sparse<'a> {
pub count: u64,
pub indices: SparseIndices<'a>,
pub values: SparseValues<'a>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
Sparse storage of accessor values that deviate from their initialization value.
Fields
count: u64Number of deviating accessor values stored in the sparse array.
indices: SparseIndices<'a>An object pointing to a buffer view containing the indices of deviating accessor values.
values: SparseValues<'a>An object pointing to a buffer view containing the deviating accessor values.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations