pub struct Texture<'a> {
pub name: Option<Cow<'a, str>>,
pub source: Option<Idx<Image<'static>>>,
pub sampler: Option<Idx<Sampler<'static>>>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
A texture and it’s sampler.
Fields
name: Option<Cow<'a, str>>The user-defined name of this object.
source: Option<Idx<Image<'static>>>The index of the image used by this texture
sampler: Option<Idx<Sampler<'static>>>The index of the sampler used by this texture.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations