pub struct TextureInfo<'a> {
pub index: Idx<Texture<'static>>,
pub texcoord: u64,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
Reference to a texture.
Fields
index: Idx<Texture<'static>>The index of the texture.
texcoord: u64The set index of texture’s TEXCOORD attribute used for texture coordinate mapping.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations
Sourceimpl TextureInfo<'_>
impl TextureInfo<'_>
Sourcepub fn into_owned(self) -> TextureInfo<'static>
pub fn into_owned(self) -> TextureInfo<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.