Wrap

Struct Wrap 

pub struct Wrap(pub u64);
Wrapping mode.

Tuple Fields

0: u64

Implementations

Source

impl Wrap

pub fn into_owned(self) -> Wrap

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl Wrap

pub const CLAMP_TO_EDGE: Self

pub const MIRRORED_REPEAT: Self

pub const REPEAT: Self

pub fn to_enum(self) -> Option<WrapEnum>