pub struct ComponentType(pub u64);Expand description
Data type of an accessor’s components.
Tuple Fields
0: u64Implementations
Sourceimpl ComponentType
impl ComponentType
Sourcepub fn into_owned(self) -> ComponentType
pub fn into_owned(self) -> ComponentType
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.