pub struct Node<'a> {
pub name: Option<Cow<'a, str>>,
pub children: Vec<Idx<Node<'static>>>,
pub camera: Option<Idx<Camera<'static>>>,
pub mesh: Option<Idx<Mesh<'static>>>,
pub skin: Option<Idx<Skin<'static>>>,
pub weights: Option<Vec<f32>>,
pub matrix: Option<[f32; 16]>,
pub rotation: Option<[f32; 4]>,
pub scale: Option<[f32; 3]>,
pub translation: Option<[f32; 3]>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
A node in the node hierarchy.
Fields
name: Option<Cow<'a, str>>The user-defined name of this object.
children: Vec<Idx<Node<'static>>>The indices of this node’s children.
camera: Option<Idx<Camera<'static>>>The index of the camera referenced by this node.
mesh: Option<Idx<Mesh<'static>>>The index of the mesh in this node.
skin: Option<Idx<Skin<'static>>>The index of the skin referenced by this node.
weights: Option<Vec<f32>>The weights of the instantiated morph target.
matrix: Option<[f32; 16]>A 4x4 transformation matrix stored in column-major order.
rotation: Option<[f32; 4]>The node’s unit quaternion rotation in the order (x, y, z, w), where w is the scalar.
scale: Option<[f32; 3]>The node’s non-uniform scale, given as the scaling factors along the x, y, and z axes.
translation: Option<[f32; 3]>The node’s translation along the x, y, and z axes.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations