pub struct OcclusionTextureInfo<'a> {
pub inner: TextureInfo<'a>,
pub strength: f32,
}Expand description
Reference to an occlusion texture.
Fields
inner: TextureInfo<'a>strength: f32A scalar multiplier controlling the amount of occlusion applied.
Implementations
Sourceimpl OcclusionTextureInfo<'_>
impl OcclusionTextureInfo<'_>
Sourcepub fn into_owned(self) -> OcclusionTextureInfo<'static>
pub fn into_owned(self) -> OcclusionTextureInfo<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.