pub struct Skin<'a> {
pub name: Option<Cow<'a, str>>,
pub skeleton: Option<Idx<Node<'static>>>,
pub joints: Vec<Idx<Node<'static>>>,
pub inverse_bind_matrices: Option<Idx<Accessor<'static>>>,
pub extensions: Option<Extensions<'a>>,
pub extras: Option<Extras<'a>>,
}Expand description
Joints and matrices defining a skin.
Fields
name: Option<Cow<'a, str>>The user-defined name of this object.
skeleton: Option<Idx<Node<'static>>>The index of the node used as a skeleton root.
joints: Vec<Idx<Node<'static>>>Indices of skeleton nodes, used as joints in this skin.
inverse_bind_matrices: Option<Idx<Accessor<'static>>>The index of the accessor containing the floating-point 4x4 inverse-bind matrices.
extensions: Option<Extensions<'a>>extras: Option<Extras<'a>>Implementations